@@ -97,11 +97,15 @@ import System.FilePath     ( (</>), (<.>) )
 import System.IO           ( Handle, hPutStr )
 import System.Exit         ( ExitCode(..), exitWith )
 import System.Process      ( runProcess, waitForProcess )
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ( (<$>), (<*>) )
+#endif
 import Control.Monad       ( when, unless )
 import Data.List           ( foldl1' )
 import Data.Maybe          ( fromMaybe, isJust )
+#if !MIN_VERSION_base(4,8,0)
 import Data.Monoid         ( mempty )
+#endif
 import Data.Char           ( isSpace )
 
 #ifdef mingw32_HOST_OS
@@ -353,8 +357,6 @@ externalSetupMethod verbosity options pkg bt mkargs = do
   installedCabalVersion :: SetupScriptOptions -> Compiler -> ProgramConfiguration
                         -> IO (Version, Maybe InstalledPackageId
                               ,SetupScriptOptions)
-  installedCabalVersion options' _ _ | packageName pkg == PackageName "Cabal" =
-    return (packageVersion pkg, Nothing, options')
   installedCabalVersion options' compiler conf = do
     index <- maybeGetInstalledPackages options' compiler conf
     let cabalDep   = Dependency (PackageName "Cabal") (useCabalVersion options')
@@ -497,7 +499,9 @@ externalSetupMethod verbosity options pkg bt mkargs = do
             , ghcOptObjDir          = Flag setupDir
             , ghcOptHiDir           = Flag setupDir
             , ghcOptSourcePathClear = Flag True
-            , ghcOptSourcePath      = toNubListR [workingDir]
+            , ghcOptSourcePath      = case bt of
+                                      Custom -> toNubListR [workingDir]
+                                      _      -> mempty
             , ghcOptPackageDBs      = usePackageDB options''
             , ghcOptPackages        = toNubListR $
                 maybe [] (\ipkgid -> [(ipkgid, cabalPkgid, defaultRenaming)])
